@@ -3,9 +3,9 @@
 package Test::Sah::Schema;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-03'; # DATE
+our $DATE = '2020-03-04'; # DATE
 our $DIST = 'Test-Sah-Schema'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -91,7 +91,7 @@ sub sah_schema_module_ok {
                             ($eg->{name} ? " ($eg->{name})" :
                              ($eg->{summary} ? " ($eg->{summary})" : "")),
                         sub {
-                            my ($errmsg, $res)  = @{ $vdr->($eg->{data}) };
+                            my ($errmsg, $res)  = @{ $vdr->($eg->{value}) };
                             if ($eg->{valid}) {
                                 if ($errmsg) {
                                     $Test->ok(0, "Data should be valid, but isn't");
@@ -254,7 +254,7 @@ Test::Sah::Schema - Test Sah::Schema::* modules in distribution
 
 =head1 VERSION
 
-This document describes version 0.002 of Test::Sah::Schema (from Perl distribution Test-Sah-Schema), released on 2020-03-03.
+This document describes version 0.003 of Test::Sah::Schema (from Perl distribution Test-Sah-Schema), released on 2020-03-04.
 
 =head1 SYNOPSIS
 
